@@ -53,9 +53,15 @@ int handle__pingreq(struct mosquitto *mosq)
 
 int handle__pingresp(struct mosquitto *mosq)
 {
+	int state;
+
 	assert(mosq);
 
-	if(mosq->state != mosq_cs_connected){
+	pthread_mutex_lock(&mosq->state_mutex);
+	state = mosq->state;
+	pthread_mutex_unlock(&mosq->state_mutex);
+
+	if(state != mosq_cs_connected){
 		return MOSQ_ERR_PROTOCOL;
 	}
 
